/*
Includes: stdio.h to do screen output and SpiceUsr.h as some CSPICE
routines will be called by this example program.
*/

#include <stdio.h>
#include "SpiceUsr.h"

/*
odt_example prototype.
*/

void odt_example( double   start,
                  double   step,
                  long     n,
                  double * tlp_length,
                  double * tlp_angle,
                  double * radius,
                  double * rad_rate,
                  double * vel_tan );

/*
Example main program calling odt_example.
*/

int main( int argc, char * argv[] )
{

   /*
   Size of ODT parameter buffers.
   */
   #define  MAXSTEP                    7200 

   /*
   odt_example inputs/output argument declarations.
   */
   double   start;
   double   step;
   long     n;
   double   tlp_angle[MAXSTEP];
   double   tlp_length[MAXSTEP];
   double   radius[MAXSTEP];
   double   rad_rate[MAXSTEP];
   double   vel_tan[MAXSTEP];
   
   /*
   Auxillary variables.
   */
   long     i;
   double   et;

   /*
   Get command line. Display usage if it doesn't contain two arguments.
   */
   if ( argc != 3 )
   {
      printf ( "                                       \n" );
      printf ( "Usage:                                 \n" );
      printf ( "                                       \n" );
      printf ( "   > run_odt_example <metakernel> <utc>\n" );
      printf ( "                                       \n" );
      return(1);
   }

   /*
   First argument on the command line is the name of a meta-kernel file
   listing SPICE files (kernels) that should be loaded.
   */
   furnsh_c( argv[1] );

   /*
   Second argument is the start time provided as a UTC string. Convert
   it to ET.
   */
   str2et_c( argv[2], &start );

   /*
   For simplicity, in this example the step in seconds and the number
   of iterations are hard coded.
   */
   step = 600.0;
   n = 12;
   
   /*
   Call odt_example to compute ODT parameters for these inputs.
   */
   odt_example( start, step, n, 
                tlp_length, tlp_angle, radius, rad_rate, vel_tan );

   /*
   Display ODT data.
   */
   for ( i = 0;  i < n; i++ )
   {
     /*
     Compute ET of this ODT record.
     */
     et = start + ( i + 1 ) * step;

     /*
     Print the record.
     */
     printf( "%12.3f %12.3f %12.3f %12.3f %12.3f %12.3f\n", 
             et, tlp_length[i], tlp_angle[i], radius[i], 
             rad_rate[i], vel_tan[i]);
   }

   /*
   All done.
   */
   return(0);

}
